@@ -53,7 +53,8 @@ class Connection(object):
 
     def rollback(self):
         self.connection.rollback()
-
+    def set(self):
+        return self.connection.set()
     def close(self):
         self.connection.close()
 
