@@ -1,5 +1,6 @@
 import sys
 import types
+from CUBRIDdb import FIELD_TYPE
 
 class BaseCursor(object):
     """
@@ -14,6 +15,7 @@ class BaseCursor(object):
     """
 
     def __init__(self, conn):
+        self.con = conn.connection
         self._cs = conn.connection.cursor()
         self.arraysize = 1
         self.rowcount = -1
@@ -33,7 +35,7 @@ class BaseCursor(object):
         except AttributeError:   # self._cs not exists
             pass
 
-    def _bind_params(self, args):
+    def _bind_params(self, args,set_type=None):
         if type(args) not in (tuple, list):
             args = [args,]
         args = list(args)
@@ -45,6 +47,8 @@ class BaseCursor(object):
                     args[i] = '1'
                 else:
                     args[i] = '0'
+            elif isinstance(args[i], tuple):
+                 args[i] = args[i]
             else:
                 # Python3.X dosen't support unicode keyword.
                 try:
@@ -61,10 +65,22 @@ class BaseCursor(object):
                         args[i] = args[i].encode(self.charset)
                     else:
                         args[i] = str(args[i])
+            
+            if type(args[i]) != tuple:
+                self._cs.bind_param(i+1, args[i])
+            else: 
+                if set_type == None:
+                    data_type = int(FIELD_TYPE.CHAR)
+                else:
+                    if type(set_type) != tuple:
+                        set_type = [set_type,]                      
+                    data_type = set_type[i]
 
-            self._cs.bind_param(i+1, args[i])
+                s = self.con.set()
+                s.imports(args[i], data_type)
+                self._cs.bind_set(i+1, s)
 
-    def execute(self, query, args=None):
+    def execute(self, query, args=None,set_type=None):
         """
         Execute a query.
         
@@ -76,7 +92,7 @@ class BaseCursor(object):
         self._cs.prepare(query)
 
         if args != None:
-            self._bind_params(args)
+            self._bind_params(args,set_type)
 
         r = self._cs.execute()
         self.rowcount = self._cs.rowcount
