@@ -34,6 +34,18 @@
 #define CUBRID_EXEC_ONLY_QUERY_PLAN CCI_EXEC_ONLY_QUERY_PLAN
 #define CUBRID_EXEC_THREAD          CCI_EXEC_THREAD
 
+#define SHRT_MIN_STR     "-32768"       /* minimum (signed) short value */
+#define SHRT_MAX_STR       "32767"         /* maximum (signed) short value */
+#define INT_MIN_STR     "-2147483648"/* minimum (signed) int value */
+#define INT_MAX_STR       "2147483647"    /* maximum (signed) int value */
+#define LLONG_MAX_STR     "9223372036854775807"       /* maximum signed long long int value */
+#define LLONG_MIN_STR   "-9223372036854775807" /* minimum signed long long int value */
+#define DBL_MAX_STR       "1.7976931348623158e+308" /* max value */
+#define DBL_MIN_STR         "2.2250738585072014e-308" /* min positive value */
+#define FLT_MAX_STR         "3.402823466e+38F"        /* max value */
+#define FLT_MIN_STR         "1.175494351e-38F"        /* min positive value */
+
+
 #ifdef MS_WINDOWS
 #define CUBRID_LONG_LONG _int64
 #else
@@ -78,7 +90,27 @@ typedef struct
   CUBRID_LONG_LONG pos;
 } _cubrid_LobObject;
 
+typedef struct
+{
+  PyObject_HEAD
+  int connection;
+  T_CCI_SET data;
+  char type;
+  CUBRID_LONG_LONG pos;
+} _cubrid_SetObject;
+
+
 extern PyTypeObject _cubrid_ConnectionObject_type;
 extern PyTypeObject _cubrid_CursorObject_type;
 extern PyTypeObject _cubrid_LobObject_type;
+extern PyTypeObject _cubrid_SetObject_type;
 
+extern int ut_str_to_bigint (char *str, CUBRID_LONG_LONG * value);
+extern int ut_str_to_int (char *str, int *value);
+extern int ut_str_to_float (char *str, float *value);
+extern int ut_str_to_double (char *str, double *value);
+extern int ut_str_to_date (char *str, T_CCI_DATE * value);
+extern int ut_str_to_time (char *str, T_CCI_DATE * value);
+extern int ut_str_to_mtime (char *str, T_CCI_DATE * value);
+extern int ut_str_to_timestamp (char *str, T_CCI_DATE * value);
+extern int ut_str_to_datetime (char *str, T_CCI_DATE * value);
\ No newline at end of file
